# -*- coding: utf-8 -*-

from admin_interface.models import Theme

from django.contrib import admin
from django.utils.translation import ugettext_lazy as _


class ThemeAdmin(admin.ModelAdmin):

    list_display = ('name', 'active', )
    list_editable = ('active', )
    list_per_page = 100
    show_full_result_count = False

    fieldsets = (
        (None, {
            'classes': ('wide', ),
            'fields': ('name', 'active', )
        }),
        (_('Environment'), {
            'classes': ('wide', ),
            'fields': (
                'env_name',
                'env_color',
                'env_visible_in_header',
                'env_visible_in_favicon',
            )
        }),
        (_('Language chooser'), {
            'classes': ('wide', ),
            'fields': (
                'language_chooser_active',
                'language_chooser_display',
            )
        }),
        (_('Logo'), {
            'classes': ('wide', ),
            'fields': (
                'logo',
                'logo_color',
                'logo_visible',
            )
        }),
        (_('Favicon'), {
            'classes': ('wide', ),
            'fields': ('favicon', )
        }),
        (_('Title'), {
            'classes': ('wide', ),
            'fields': (
                'title',
                'title_color',
                'title_visible',
            )
        }),
        (_('Header'), {
            'classes': ('wide', ),
            'fields': (
                'css_header_background_color',
                'css_header_text_color',
                'css_header_link_color',
                'css_header_link_hover_color',
            )
        }),
        (_('Breadcrumbs / Module headers'), {
            'classes': ('wide', ),
            'fields': (
                'css_module_background_color',
                'css_module_text_color',
                'css_module_link_color',
                'css_module_link_hover_color',
                'css_module_rounded_corners',
            )
        }),
        (_('Generic Links'), {
            'classes': ('wide', ),
            'fields': (
                'css_generic_link_color',
                'css_generic_link_hover_color',
            )
        }),
        (_('Save Buttons'), {
            'classes': ('wide', ),
            'fields': (
                'css_save_button_background_color',
                'css_save_button_background_hover_color',
                'css_save_button_text_color',
            )
        }),
        (_('Delete Buttons'), {
            'classes': ('wide', ),
            'fields': (
                'css_delete_button_background_color',
                'css_delete_button_background_hover_color',
                'css_delete_button_text_color',
            )
        }),
        (_('Related Modal'), {
            'classes': ('wide', ),
            'fields': (
                'related_modal_active',
                'related_modal_background_color',
                'related_modal_background_opacity',
                'related_modal_rounded_corners',
                'related_modal_close_button_visible',
            )
        }),
        (_('List Filter'), {
            'classes': ('wide', ),
            'fields': ('list_filter_dropdown', )
        }),
        (_('Recent Actions'), {
            'classes': ('wide', ),
            'fields': ('recent_actions_visible', )
        }),
    )

    save_on_top = True


admin.site.register(Theme, ThemeAdmin)



# -*- coding: utf-8 -*-

from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('admin_interface', '0007_add_favicon'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='theme',
            name='related_modal_background_opacity'
        ),
        migrations.AddField(
            model_name='theme',
            name='related_modal_background_opacity',
            field=models.CharField(
                choices=[
                    ('0.1', '10%'), ('0.2', '20%'), ('0.3', '30%'),
                    ('0.4', '40%'), ('0.5', '50%'), ('0.6', '60%'),
                    ('0.7', '70%'), ('0.8', '80%'), ('0.9', '90%')],
                default='0.3',
                help_text='20%',
                max_length=5,
                verbose_name='background opacity'),
        ),
    ]



# -*- coding: utf-8 -*-

from __future__ import unicode_literals

import colorfield.fields

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('admin_interface', '0010_add_localization'),
    ]

    operations = [
        migrations.RenameField(
            model_name='theme',
            old_name='env',
            new_name='env_name',
        ),
        migrations.AlterField(
            model_name='theme',
            name='env_name',
            field=models.CharField(
                blank=True,
                max_length=50,
                verbose_name='name'),
        ),
        migrations.AddField(
            model_name='theme',
            name='env_color',
            field=colorfield.fields.ColorField(
                blank=True,
                default='#E74C3C',
                help_text='(red: #E74C3C, orange: #E67E22, yellow: #F1C40F, green: #2ECC71, blue: #3498DB)',
                max_length=10,
                verbose_name='color'),
        ),
        migrations.RenameField(
            model_name='theme',
            old_name='env_visible',
            new_name='env_visible_in_header',
        ),
        migrations.AlterField(
            model_name='theme',
            name='env_visible_in_header',
            field=models.BooleanField(
                default=True,
                verbose_name='visible in header (marker and name)'),
        ),
        migrations.AddField(
            model_name='theme',
            name='env_visible_in_favicon',
            field=models.BooleanField(
                default=True,
                verbose_name='visible in favicon (marker)'),
        ),
    ]



# -*- coding: utf-8 -*-

from __future__ import unicode_literals

from django.db import migrations, models

import colorfield.fields


class Migration(migrations.Migration):

    dependencies = [
        ('admin_interface', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='theme',
            name='list_filter_dropdown',
            field=models.BooleanField(
                default=False,
                verbose_name=b'use dropdown'),
        ),
        migrations.AddField(
            model_name='theme',
            name='related_modal_active',
            field=models.BooleanField(
                default=True,
                verbose_name=b'active'),
        ),
        migrations.AddField(
            model_name='theme',
            name='related_modal_background_color',
            field=colorfield.fields.ColorField(
                blank=True,
                default=b'#000000',
                help_text=b'#000000',
                max_length=10,
                verbose_name=b'background color'),
        ),
        migrations.AddField(
            model_name='theme',
            name='related_modal_background_opacity',
            field=models.FloatField(
                choices=[
                    (0.1, b'10%'), (0.2, b'20%'), (0.3, b'30%'),
                    (0.4, b'40%'), (0.5, b'50%'), (0.6, b'60%'),
                    (0.7, b'70%'), (0.8, b'80%'), (0.9, b'90%')],
                default=0.2,
                help_text=b'20%',
                verbose_name=b'background opacity'),
        ),
        migrations.AddField(
            model_name='theme',
            name='related_modal_rounded_corners',
            field=models.BooleanField(
                default=True,
                verbose_name=b'rounded corners'),
        ),
    ]



# -*- coding: utf-8 -*-

import django
from django import template, VERSION
from django.conf import settings
if django.VERSION < (1, 10):
    from django.core.urlresolvers import NoReverseMatch, reverse
else:
    from django.urls import NoReverseMatch, reverse
from django.utils import translation

from admin_interface.cache import get_cached_active_theme, set_cached_active_theme
from admin_interface.models import Theme
from admin_interface.version import __version__

import re


register = template.Library()

if VERSION < (1, 9):
    simple_tag = register.assignment_tag
else:
    simple_tag = register.simple_tag


@simple_tag(takes_context=True)
def get_admin_interface_languages(context):
    if not settings.USE_I18N:
        # i18n disabled
        return None
    if len(settings.LANGUAGES) < 2:
        # less than 2 languages
        return None
    try:
        set_language_url = reverse('set_language')
    except NoReverseMatch:
        # ImproperlyConfigured - must include i18n urls:
        # urlpatterns += [url(r'^i18n/', include('django.conf.urls.i18n')),]
        return None
    request = context.get('request', None)
    if not request:
        return None
    full_path = request.get_full_path()
    admin_nolang_url = re.sub(r'^\/([\w]{2})([\-\_]{1}[\w]{2})?\/', '/', full_path)
    if admin_nolang_url == full_path:
        # ImproperlyConfigured - must include admin urls using i18n_patterns:
        # from django.conf.urls.i18n import i18n_patterns
        # urlpatterns += i18n_patterns(url(r'^admin/', admin.site.urls))
        return None
    langs_data = []
    default_lang_code = settings.LANGUAGE_CODE
    current_lang_code = translation.get_language() or default_lang_code
    for language in settings.LANGUAGES:
        lang_code = language[0].lower()
        lang_name = language[1].title()
        lang_data = {
            'code': lang_code,
            'name': lang_name,
            'default': lang_code == default_lang_code,
            'active': lang_code == current_lang_code,
            'activation_url': '{}?next=/{}{}'.format(
                set_language_url, lang_code, admin_nolang_url)
        }
        langs_data.append(lang_data)
    return langs_data


@simple_tag(takes_context=True)
def get_admin_interface_theme(context):
    theme = get_cached_active_theme()
    if not theme:
        theme = Theme.get_active_theme()
        set_cached_active_theme(theme)
    return theme


@simple_tag(takes_context=False)
def get_admin_interface_version():
    return __version__



# -*- coding: utf-8 -*-

from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('admin_interface', '0012_update_verbose_names'),
    ]

    operations = [
        migrations.AddField(
            model_name='theme',
            name='related_modal_close_button_visible',
            field=models.BooleanField(default=True, verbose_name='close button visible'),
        ),
    ]



# -*- coding: utf-8 -*-

from __future__ import unicode_literals

import colorfield.fields

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('admin_interface', '0005_add_recent_actions_visible'),
    ]

    operations = [
        migrations.AlterField(
            model_name='theme',
            name='css_delete_button_background_color',
            field=colorfield.fields.ColorField(
                blank=True,
                default='#BA2121',
                help_text='#BA2121',
                max_length=10,
                verbose_name='background color'),
        ),
        migrations.AlterField(
            model_name='theme',
            name='css_delete_button_background_hover_color',
            field=colorfield.fields.ColorField(
                blank=True,
                default='#A41515',
                help_text='#A41515',
                max_length=10,
                verbose_name='background hover color'),
        ),
        migrations.AlterField(
            model_name='theme',
            name='css_delete_button_text_color',
            field=colorfield.fields.ColorField(
                blank=True,
                default='#FFFFFF',
                help_text='#FFFFFF',
                max_length=10,
                verbose_name='text color'),
        ),
        migrations.AlterField(
            model_name='theme',
            name='css_generic_link_color',
            field=colorfield.fields.ColorField(
                blank=True,
                default='#0C3C26',
                help_text='#0C3C26',
                max_length=10,
                verbose_name='link color'),
        ),
        migrations.AlterField(
            model_name='theme',
            name='css_generic_link_hover_color',
            field=colorfield.fields.ColorField(
                blank=True,
                default='#156641',
                help_text='#156641',
                max_length=10,
                verbose_name='link hover color'),
        ),
        migrations.AlterField(
            model_name='theme',
            name='css_header_background_color',
            field=colorfield.fields.ColorField(
                blank=True,
                default='#0C4B33',
                help_text='#0C4B33',
                max_length=10,
                verbose_name='background color'),
        ),
        migrations.AlterField(
            model_name='theme',
            name='css_header_link_color',
            field=colorfield.fields.ColorField(
                blank=True,
                default='#FFFFFF',
                help_text='#FFFFFF',
                max_length=10,
                verbose_name='link color'),
        ),
        migrations.AlterField(
            model_name='theme',
            name='css_header_link_hover_color',
            field=colorfield.fields.ColorField(
                blank=True,
                default='#C9F0DD',
                help_text='#C9F0DD',
                max_length=10,
                verbose_name='link hover color'),
        ),
        migrations.AlterField(
            model_name='theme',
            name='css_header_text_color',
            field=colorfield.fields.ColorField(
                blank=True,
                default='#44B78B',
                help_text='#44B78B',
                max_length=10,
                verbose_name='text color'),
        ),
        migrations.AlterField(
            model_name='theme',
            name='css_module_background_color',
            field=colorfield.fields.ColorField(
                blank=True,
                default='#44B78B',
                help_text='#44B78B',
                max_length=10,
                verbose_name='background color'),
        ),
        migrations.AlterField(
            model_name='theme',
            name='css_module_link_color',
            field=colorfield.fields.ColorField(
                blank=True,
                default='#FFFFFF',
                help_text='#FFFFFF',
                max_length=10,
                verbose_name='link color'),
        ),
        migrations.AlterField(
            model_name='theme',
            name='css_module_link_hover_color',
            field=colorfield.fields.ColorField(
                blank=True,
                default='#C9F0DD',
                help_text='#C9F0DD',
                max_length=10,
                verbose_name='link hover color'),
        ),
        migrations.AlterField(
            model_name='theme',
            name='css_module_rounded_corners',
            field=models.BooleanField(
                default=True,
                verbose_name='rounded corners'),
        ),
        migrations.AlterField(
            model_name='theme',
            name='css_module_text_color',
            field=colorfield.fields.ColorField(
                blank=True,
                default='#FFFFFF',
                help_text='#FFFFFF',
                max_length=10,
                verbose_name='text color'),
        ),
        migrations.AlterField(
            model_name='theme',
            name='css_save_button_background_color',
            field=colorfield.fields.ColorField(
                blank=True,
                default='#0C4B33',
                help_text='#0C4B33',
                max_length=10,
                verbose_name='background color'),
        ),
        migrations.AlterField(
            model_name='theme',
            name='css_save_button_background_hover_color',
            field=colorfield.fields.ColorField(
                blank=True,
                default='#0C3C26',
                help_text='#0C3C26',
                max_length=10,
                verbose_name='background hover color'),
        ),
        migrations.AlterField(
            model_name='theme',
            name='css_save_button_text_color',
            field=colorfield.fields.ColorField(
                blank=True,
                default='#FFFFFF',
                help_text='#FFFFFF',
                max_length=10,
                verbose_name='text color'),
        ),
        migrations.AlterField(
            model_name='theme',
            name='list_filter_dropdown',
            field=models.BooleanField(
                default=False,
                verbose_name='use dropdown'),
        ),
        migrations.AlterField(
            model_name='theme',
            name='logo_visible',
            field=models.BooleanField(
                default=True,
                verbose_name='visible'),
        ),
        migrations.AlterField(
            model_name='theme',
            name='name',
            field=models.CharField(
                default='Django',
                max_length=50),
        ),
        migrations.AlterField(
            model_name='theme',
            name='related_modal_active',
            field=models.BooleanField(
                default=True,
                verbose_name='active'),
        ),
        migrations.AlterField(
            model_name='theme',
            name='related_modal_background_color',
            field=colorfield.fields.ColorField(
                blank=True,
                default='#000000',
                help_text='#000000',
                max_length=10,
                verbose_name='background color'),
        ),
        migrations.AlterField(
            model_name='theme',
            name='related_modal_background_opacity',
            field=models.FloatField(
                choices=[
                    (0.1, '10%'), (0.2, '20%'), (0.3, '30%'),
                    (0.4, '40%'), (0.5, '50%'), (0.6, '60%'),
                    (0.7, '70%'), (0.8, '80%'), (0.9, '90%')],
                default=0.2,
                help_text='20%',
                verbose_name='background opacity'),
        ),
        migrations.AlterField(
            model_name='theme',
            name='related_modal_rounded_corners',
            field=models.BooleanField(
                default=True,
                verbose_name='rounded corners'),
        ),
        migrations.AlterField(
            model_name='theme',
            name='title',
            field=models.CharField(
                blank=True,
                default='Django administration',
                max_length=50),
        ),
        migrations.AlterField(
            model_name='theme',
            name='title_color',
            field=colorfield.fields.ColorField(
                blank=True,
                default='#F5DD5D',
                help_text='#F5DD5D',
                max_length=10,
                verbose_name='title color'),
        ),
        migrations.AlterField(
            model_name='theme',
            name='title_visible',
            field=models.BooleanField(
                default=True,
                verbose_name='visible'),
        ),
    ]



# -*- coding: utf-8 -*-

from __future__ import unicode_literals

import colorfield.fields

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('admin_interface', '0011_add_environment_options'),
    ]

    operations = [
        migrations.AlterField(
            model_name='theme',
            name='logo_color',
            field=colorfield.fields.ColorField(blank=True, default='#FFFFFF', help_text='#FFFFFF', max_length=10, verbose_name='color'),
        ),
        migrations.AlterField(
            model_name='theme',
            name='title_color',
            field=colorfield.fields.ColorField(blank=True, default='#F5DD5D', help_text='#F5DD5D', max_length=10, verbose_name='color'),
        ),
    ]



# -*- coding: utf-8 -*-

from django.conf import settings
from django.core.cache import cache, caches


def app_cache():
    return caches['admin_interface'] if 'admin_interface' in settings.CACHES else cache


def del_cached_active_theme():
    app_cache().delete('admin_interface_theme')


def get_cached_active_theme():
    return app_cache().get('admin_interface_theme', None)


def set_cached_active_theme(theme):
    app_cache().set('admin_interface_theme', theme)



# -*- coding: utf-8 -*-

from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('admin_interface', '0013_add_related_modal_close_button'),
    ]

    operations = [
        migrations.AlterField(
            model_name='theme',
            name='name',
            field=models.CharField(default='Django', max_length=50, unique=True, verbose_name='name'),
        ),
    ]



# -*- coding: utf-8 -*-

from __future__ import unicode_literals

import colorfield.fields

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('admin_interface', '0002_add_related_modal'),
    ]

    operations = [
        migrations.AddField(
            model_name='theme',
            name='logo_color',
            field=colorfield.fields.ColorField(
                blank=True,
                default='#FFFFFF',
                help_text='#FFFFFF',
                max_length=10,
                verbose_name='logo color'),
        ),
        migrations.AlterField(
            model_name='theme',
            name='logo',
            field=models.FileField(
                blank=True,
                help_text='(leave blank to use the default Django logo)',
                upload_to='admin-interface/logo/'),
        ),
    ]



# -*- coding: utf-8 -*-

from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('admin_interface', '0006_bytes_to_str'),
    ]

    operations = [
        migrations.AddField(
            model_name='theme',
            name='favicon',
            field=models.FileField(
                blank=True,
                help_text='(.ico|.png|.gif - 16x16|32x32 px)',
                upload_to='admin-interface/favicon/',
                verbose_name='favicon'),
        ),
    ]



# -*- coding: utf-8 -*-

from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('admin_interface', '0015_add_language_chooser_active'),
    ]

    operations = [
        migrations.AddField(
            model_name='theme',
            name='language_chooser_display',
            field=models.CharField(choices=[('code', 'code'), ('name', 'name')], default='code', max_length=10, verbose_name='display'),
        ),
    ]



# -*- coding: utf-8 -*-

from __future__ import unicode_literals

from admin_interface.cache import del_cached_active_theme

from colorfield.fields import ColorField

from django.db import models
from django.db.models.signals import post_delete, post_save, pre_save
from django.utils.encoding import force_text
from django.utils.translation import ugettext_lazy as _

from six import python_2_unicode_compatible


@python_2_unicode_compatible
class Theme(models.Model):

    @staticmethod
    def post_migrate_handler(**kwargs):
        del_cached_active_theme()
        Theme.get_active_theme()

    @staticmethod
    def post_delete_handler(**kwargs):
        del_cached_active_theme()
        Theme.get_active_theme()

    @staticmethod
    def post_save_handler(instance, **kwargs):
        del_cached_active_theme()
        if instance.active:
            Theme.objects.exclude(pk=instance.pk).update(active=False)
        Theme.get_active_theme()

    @staticmethod
    def pre_save_handler(instance, **kwargs):
        if instance.pk is None:
            try:
                obj = Theme.objects.get(name=instance.name)
                if obj:
                    instance.pk = obj.pk
            except Theme.DoesNotExist:
                pass

    @staticmethod
    def get_active_theme():
        objs_manager = Theme.objects
        objs_active_qs = objs_manager.filter(active=True)
        objs_active_ls = list(objs_active_qs)
        objs_active_count = len(objs_active_ls)

        if objs_active_count == 0:
            obj = objs_manager.all().first()
            if obj:
                obj.set_active()
            else:
                obj = objs_manager.create()

        elif objs_active_count == 1:
            obj = objs_active_ls[0]

        elif objs_active_count > 1:
            obj = objs_active_ls[-1]
            obj.set_active()

        return obj

    name = models.CharField(
        unique=True,
        max_length=50,
        default='Django',
        verbose_name=_('name'))
    active = models.BooleanField(
        default=True,
        verbose_name=_('active'))

    title = models.CharField(
        max_length=50,
        default=_('Django administration'),
        blank=True,
        verbose_name=_('title'))
    title_color = ColorField(
        blank=True,
        default='#F5DD5D',
        help_text='#F5DD5D',
        max_length=10,
        verbose_name=_('color'))
    title_visible = models.BooleanField(
        default=True,
        verbose_name=_('visible'))

    logo = models.FileField(
        upload_to='admin-interface/logo/',
        blank=True,
        help_text=_('Leave blank to use the default Django logo'),
        verbose_name=_('logo'))
    logo_color = ColorField(
        blank=True,
        default='#FFFFFF',
        help_text='#FFFFFF',
        max_length=10,
        verbose_name=_('color'))
    logo_visible = models.BooleanField(
        default=True,
        verbose_name=_('visible'))

    favicon = models.FileField(
        upload_to='admin-interface/favicon/',
        blank=True,
        help_text=_('(.ico|.png|.gif - 16x16|32x32 px)'),
        verbose_name=_('favicon'))

    env_name = models.CharField(
        blank=True,
        max_length=50,
        verbose_name=_('name'))
    env_color = ColorField(
        blank=True,
        default='#E74C3C',
        help_text=_('(red: #E74C3C, orange: #E67E22, yellow: #F1C40F, green: #2ECC71, blue: #3498DB)'),
        max_length=10,
        verbose_name=_('color'))
    env_visible_in_header = models.BooleanField(
        default=True,
        verbose_name=_('visible in header (marker and name)'))
    env_visible_in_favicon = models.BooleanField(
        default=True,
        verbose_name=_('visible in favicon (marker)'))

    language_chooser_active = models.BooleanField(
        default=True,
        verbose_name=_('active'))
    language_chooser_display_choices = (
        ('code', _('code'), ),
        ('name', _('name'), ),
    )
    language_chooser_display = models.CharField(
        max_length=10,
        choices=language_chooser_display_choices,
        default='code',
        verbose_name=_('display'))

    css_header_background_color = ColorField(
        blank=True,
        default='#0C4B33',
        help_text='#0C4B33',
        max_length=10,
        verbose_name=_('background color'))
    css_header_text_color = ColorField(
        blank=True,
        default='#44B78B',
        help_text='#44B78B',
        max_length=10,
        verbose_name=_('text color'))
    css_header_link_color = ColorField(
        blank=True,
        default='#FFFFFF',
        help_text='#FFFFFF',
        max_length=10,
        verbose_name=_('link color'))
    css_header_link_hover_color = ColorField(
        blank=True,
        default='#C9F0DD',
        help_text='#C9F0DD',
        max_length=10,
        verbose_name=_('link hover color'))

    css_module_background_color = ColorField(
        blank=True,
        default='#44B78B',
        help_text='#44B78B',
        max_length=10,
        verbose_name=_('background color'))
    css_module_text_color = ColorField(
        blank=True,
        default='#FFFFFF',
        help_text='#FFFFFF',
        max_length=10,
        verbose_name=_('text color'))
    css_module_link_color = ColorField(
        blank=True,
        default='#FFFFFF',
        help_text='#FFFFFF',
        max_length=10,
        verbose_name=_('link color'))
    css_module_link_hover_color = ColorField(
        blank=True,
        default='#C9F0DD',
        help_text='#C9F0DD',
        max_length=10,
        verbose_name=_('link hover color'))
    css_module_rounded_corners = models.BooleanField(
        default=True,
        verbose_name=_('rounded corners'))

    css_generic_link_color = ColorField(
        blank=True,
        default='#0C3C26',
        help_text='#0C3C26',
        max_length=10,
        verbose_name=_('link color'))
    css_generic_link_hover_color = ColorField(
        blank=True,
        default='#156641',
        help_text='#156641',
        max_length=10,
        verbose_name=_('link hover color'))

    css_save_button_background_color = ColorField(
        blank=True,
        default='#0C4B33',
        help_text='#0C4B33',
        max_length=10,
        verbose_name=_('background color'))
    css_save_button_background_hover_color = ColorField(
        blank=True,
        default='#0C3C26',
        help_text='#0C3C26',
        max_length=10,
        verbose_name=_('background hover color'))
    css_save_button_text_color = ColorField(
        blank=True,
        default='#FFFFFF',
        help_text='#FFFFFF',
        max_length=10,
        verbose_name=_('text color'))

    css_delete_button_background_color = ColorField(
        blank=True,
        default='#BA2121',
        help_text='#BA2121',
        max_length=10,
        verbose_name=_('background color'))
    css_delete_button_background_hover_color = ColorField(
        blank=True,
        default='#A41515',
        help_text='#A41515',
        max_length=10,
        verbose_name=_('background hover color'))
    css_delete_button_text_color = ColorField(
        blank=True,
        default='#FFFFFF',
        help_text='#FFFFFF',
        max_length=10,
        verbose_name=_('text color'))

    css = models.TextField(
        blank=True,
        verbose_name=_('text color'))

    related_modal_active = models.BooleanField(
        default=True,
        verbose_name=_('active'))
    related_modal_background_color = ColorField(
        blank=True,
        default='#000000',
        help_text='#000000',
        max_length=10,
        verbose_name=_('background color'))
    related_modal_background_opacity_choices = (
        ('0.1', '10%', ),
        ('0.2', '20%', ),
        ('0.3', '30%', ),
        ('0.4', '40%', ),
        ('0.5', '50%', ),
        ('0.6', '60%', ),
        ('0.7', '70%', ),
        ('0.8', '80%', ),
        ('0.9', '90%', ),
    )
    related_modal_background_opacity = models.CharField(
        max_length=5,
        choices=related_modal_background_opacity_choices,
        default='0.3',
        help_text='20%',
        verbose_name=_('background opacity'))
    related_modal_rounded_corners = models.BooleanField(
        default=True,
        verbose_name=_('rounded corners'))
    related_modal_close_button_visible = models.BooleanField(
        default=True,
        verbose_name=_('close button visible'))

    list_filter_dropdown = models.BooleanField(
        default=False,
        verbose_name=_('use dropdown'))
    recent_actions_visible = models.BooleanField(
        default=True,
        verbose_name=_('visible'))

    def set_active(self):
        self.active = True
        self.save()

    class Meta:
        app_label = 'admin_interface'

        verbose_name = _('Theme')
        verbose_name_plural = _('Themes')

    def __str__(self):
        return force_text(self.name)


post_delete.connect(Theme.post_delete_handler, sender=Theme)
post_save.connect(Theme.post_save_handler, sender=Theme)
pre_save.connect(Theme.pre_save_handler, sender=Theme)



# -*- coding: utf-8 -*-

from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('admin_interface', '0009_add_enviroment'),
    ]

    operations = [
        migrations.AlterField(
            model_name='theme',
            name='active',
            field=models.BooleanField(default=True, verbose_name='active'),
        ),
        migrations.AlterField(
            model_name='theme',
            name='css',
            field=models.TextField(blank=True, verbose_name='text color'),
        ),
        migrations.AlterField(
            model_name='theme',
            name='env',
            field=models.CharField(choices=[('development', 'Development'), ('testing', 'Testing'), ('staging', 'Staging'), ('production', 'Production')], default='development', max_length=50, verbose_name='environment'),
        ),
        migrations.AlterField(
            model_name='theme',
            name='logo',
            field=models.FileField(blank=True, help_text='Leave blank to use the default Django logo', upload_to='admin-interface/logo/', verbose_name='logo'),
        ),
        migrations.AlterField(
            model_name='theme',
            name='name',
            field=models.CharField(default='Django', max_length=50, verbose_name='name'),
        ),
        migrations.AlterField(
            model_name='theme',
            name='title',
            field=models.CharField(blank=True, default='Django administration', max_length=50, verbose_name='title'),
        ),
    ]



# -*- coding: utf-8 -*-

from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('admin_interface', '0003_add_logo_color'),
    ]

    operations = [
        migrations.RenameField(
            model_name='theme',
            old_name='css_header_title_color',
            new_name='title_color',
        ),
    ]



# -*- coding: utf-8 -*-

import django
from django.conf import settings
from django.core.exceptions import ImproperlyConfigured


def check_installed_app(app, app_dj_version_limit):
    dj_version = django.VERSION
    installed_apps = settings.INSTALLED_APPS
    if dj_version < app_dj_version_limit:
        if app not in installed_apps:
            raise ImproperlyConfigured(
                '\'{}\' needed before django {}.{}, '
                'add it to settings.INSTALLED_APPS.'.format(
                    app, *app_dj_version_limit))
    else:
        if app in installed_apps:
            raise ImproperlyConfigured(
                '\'{}\' not needed since django {}.{}, '
                'remove it from settings.INSTALLED_APPS.'.format(
                    app, *app_dj_version_limit))


def check_installed_apps():
    check_installed_app('colorfield', (4, 0))
    check_installed_app('flat', (1, 9))
    check_installed_app('flat_responsive', (2, 0))



# -*- coding: utf-8 -*-

from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('admin_interface', '0008_change_related_modal_background_opacity_type'),
    ]

    operations = [
        migrations.AddField(
            model_name='theme',
            name='env',
            field=models.CharField(choices=[('development', 'Development'), ('testing', 'Testing'), ('staging', 'Staging'), ('production', 'Production')], default='development', max_length=50, verbose_name='enviroment'),
        ),
        migrations.AddField(
            model_name='theme',
            name='env_visible',
            field=models.BooleanField(default=True, verbose_name='visible'),
        ),
    ]



# -*- coding: utf-8 -*-

from __future__ import unicode_literals

from django.db import models, migrations

import colorfield.fields


class Migration(migrations.Migration):

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Theme',
            fields=[
                ('id',
                    models.AutoField(
                        verbose_name='ID',
                        serialize=False,
                        auto_created=True,
                        primary_key=True)),
                ('name',
                    models.CharField(
                        default=b'Django',
                        max_length=50)),
                ('active',
                    models.BooleanField(
                        default=True)),
                ('title',
                    models.CharField(
                        default=b'Django administration',
                        max_length=50,
                        blank=True)),
                ('title_visible',
                    models.BooleanField(
                        default=True,
                        verbose_name=b'visible')),
                ('logo',
                    models.FileField(
                        upload_to=b'admin-interface/logo/',
                        blank=True)),
                ('logo_visible',
                    models.BooleanField(
                        default=True,
                        verbose_name=b'visible')),
                ('css_header_background_color',
                    colorfield.fields.ColorField(
                        default=b'#0C4B33',
                        help_text=b'#0C4B33',
                        max_length=10,
                        verbose_name=b'background color',
                        blank=True)),
                ('css_header_title_color',
                    colorfield.fields.ColorField(
                        default=b'#F5DD5D',
                        help_text=b'#F5DD5D',
                        max_length=10,
                        verbose_name=b'title color',
                        blank=True)),
                ('css_header_text_color',
                    colorfield.fields.ColorField(
                        default=b'#44B78B',
                        help_text=b'#44B78B',
                        max_length=10,
                        verbose_name=b'text color',
                        blank=True)),
                ('css_header_link_color',
                    colorfield.fields.ColorField(
                        default=b'#FFFFFF',
                        help_text=b'#FFFFFF',
                        max_length=10,
                        verbose_name=b'link color',
                        blank=True)),
                ('css_header_link_hover_color',
                    colorfield.fields.ColorField(
                        default=b'#C9F0DD',
                        help_text=b'#C9F0DD',
                        max_length=10,
                        verbose_name=b'link hover color',
                        blank=True)),
                ('css_module_background_color',
                    colorfield.fields.ColorField(
                        default=b'#44B78B',
                        help_text=b'#44B78B',
                        max_length=10,
                        verbose_name=b'background color',
                        blank=True)),
                ('css_module_text_color',
                    colorfield.fields.ColorField(
                        default=b'#FFFFFF',
                        help_text=b'#FFFFFF',
                        max_length=10,
                        verbose_name=b'text color',
                        blank=True)),
                ('css_module_link_color',
                    colorfield.fields.ColorField(
                        default=b'#FFFFFF',
                        help_text=b'#FFFFFF',
                        max_length=10,
                        verbose_name=b'link color',
                        blank=True)),
                ('css_module_link_hover_color',
                    colorfield.fields.ColorField(
                        default=b'#C9F0DD',
                        help_text=b'#C9F0DD',
                        max_length=10,
                        verbose_name=b'link hover color',
                        blank=True)),
                ('css_module_rounded_corners',
                    models.BooleanField(
                        default=True,
                        verbose_name=b'rounded corners')),
                ('css_generic_link_color',
                    colorfield.fields.ColorField(
                        default=b'#0C3C26',
                        help_text=b'#0C3C26',
                        max_length=10,
                        verbose_name=b'link color',
                        blank=True)),
                ('css_generic_link_hover_color',
                    colorfield.fields.ColorField(
                        default=b'#156641',
                        help_text=b'#156641',
                        max_length=10,
                        verbose_name=b'link hover color',
                        blank=True)),
                ('css_save_button_background_color',
                    colorfield.fields.ColorField(
                        default=b'#0C4B33',
                        help_text=b'#0C4B33',
                        max_length=10,
                        verbose_name=b'background color',
                        blank=True)),
                ('css_save_button_background_hover_color',
                    colorfield.fields.ColorField(
                        default=b'#0C3C26',
                        help_text=b'#0C3C26',
                        max_length=10,
                        verbose_name=b'background hover color',
                        blank=True)),
                ('css_save_button_text_color',
                    colorfield.fields.ColorField(
                        default=b'#FFFFFF',
                        help_text=b'#FFFFFF',
                        max_length=10,
                        verbose_name=b'text color',
                        blank=True)),
                ('css_delete_button_background_color',
                    colorfield.fields.ColorField(
                        default=b'#BA2121',
                        help_text=b'#BA2121',
                        max_length=10,
                        verbose_name=b'background color',
                        blank=True)),
                ('css_delete_button_background_hover_color',
                    colorfield.fields.ColorField(
                        default=b'#A41515',
                        help_text=b'#A41515',
                        max_length=10,
                        verbose_name=b'background hover color',
                        blank=True)),
                ('css_delete_button_text_color',
                    colorfield.fields.ColorField(
                        default=b'#FFFFFF',
                        help_text=b'#FFFFFF',
                        max_length=10,
                        verbose_name=b'text color',
                        blank=True)),
                ('css',
                    models.TextField(
                        blank=True)),
                ('list_filter_dropdown',
                    models.BooleanField(
                        default=False)),
            ],
            options={
                'verbose_name': 'Theme',
                'verbose_name_plural': 'Themes',
            },
        ),
    ]



# -*- coding: utf-8 -*-

from django.apps import AppConfig
from django.db.models.signals import post_migrate
from django.utils.translation import ugettext_lazy as _


class AdminInterfaceConfig(AppConfig):

    name = 'admin_interface'
    verbose_name = _('Admin Interface')

    def ready(self):

        from admin_interface import settings
        from admin_interface.models import Theme

        settings.check_installed_apps()
        post_migrate.connect(
            Theme.post_migrate_handler, sender=self)
